; *********************************************
; Constants
; *********************************************		
GM04		equ 	$F8 			; colour graphics mode 4 (PMODE 0)

PIA0_PDRA	equ 	$ff00
PIA1_PDRB	equ 	$ff22 			; peripheral interface adapter 1 data register B	
SCREEN1		equ 	$0200 			
SCREEN2		equ 	$1A00

; *********************************************
; Init
; *********************************************		
		SETDP $3200
		ORG   $3200

START	; setup VDG & SAM	
		lda 	PIA1_PDRB
		anda 	#$07 			; preserve bits 0-2
		ora 	#GM04 			; overwrite bits 8-3
		sta 	PIA1_PDRB
		JSR		CHGPGE0
		;  000 111
		STA   $FFC0   ; [SAM VDG Reg V0] = A 
		STA   $FFC3   ; [SAM VDG Reg V1] = A 
		STA   $FFC5   ; [SAM VDG Reg V2] = A 
		;  110 -> 6144 (0x1800) bytes per page

		; Clear 2 screen pages
		LDA		#$00
		STA		SCRPGE
		STA		ROWOFF
		LDX		#SCREEN1
		BSR 	PCLS
		LDX		#SCREEN2
		BSR 	PCLS
		
; *********************************************
; MAIN LOOP
; *********************************************	

MAINLO  
		LDX		#SCREEN1
		; Set the new screen page
		LDA		SCRPGE
		CMPA	$00
		BNE		SETPAG2
		LEAX	6144,X
		LDA		#1
		JMP 	SETPAG
SETPAG2	LDA		#0
SETPAG	STA		SCRPGE
		; Clean screen page
		BSR 	PCLS
		; Draw tiles
		LDA		ROWOFF
LOOPROW	CMPA	$00
		BEQ		FOL
		LEAX	32,X
		DECA
		JMP		LOOPROW
FOL		JSR 	DRWTTL
		; Wait loop
		;BSR 	WAIT
		; Show the new screen page
		BSR		CHGPGE
		; Move tiles down
		LDA		ROWOFF
		INCA
		CMPA	#177
		BNE		CONT
		LDA		#0
CONT	STA		ROWOFF
		JMP 	MAINLO
		
; *********************************************
; PCLS: Clear screen
; *********************************************	

PCLS   	PSHS	X
		LDY		#6144
		CLRA
		CLRB
PCLSL1 	STD   	,X++
		LEAY	-2,Y
		BNE   	PCLSL1
		PULS	X,PC

; *********************************************
; DRWTTL
; *********************************************	

DRWTTL  LDY   #TDATA
		LDB   #16
LOOP4	LDA   #16
LOOP3	LDU   ,Y++
		STU   ,X
		LEAX  32,X
		DECA
		BNE   LOOP3
		LEAY  -32,Y
		LEAX  -510,X
		DECB
		BNE   LOOP4
		RTS

; *********************************************
; WAIT: delay loop
; *********************************************	

WAIT	PSHS	X			; Delay loop
		LDX		#$900
LOOP	LEAX	-1,X
		BNE		LOOP
		PULS	X,PC
		
; *********************************************
; CHGPGE: change graphics page 0/1
; *********************************************	

CHGPGE  LDA		SCRPGE
		CMPA	#$00
		BNE		CHGPGE1
CHGPGE0	STA		$FFC7   ; [SAM Display Offset bit F0] = 1 
		STA		$FFC8   ; [SAM Display Offset bit F1] = 0 
		STA		$FFCA   ; [SAM Display Offset bit F2] = 0 
		STA		$FFCC   ; [SAM Display Offset bit F3] = 0 
		RTS
CHGPGE1	STA		$FFC7   ; [SAM Display Offset bit F0] = 1 
		STA		$FFC8   ; [SAM Display Offset bit F1] = 0 
		STA		$FFCB   ; [SAM Display Offset bit F2] = 1 
		STA		$FFCD   ; [SAM Display Offset bit F3] = 1
		RTS

; **
; Variables
; **
TDATA  FDB   	$FFFF,$C003,$A005,$9009,$8811,$8421,$8241,$8181,$8181,$8241,$8421,$8811,$9009,$A005,$C003,$FFFF
SCRPGE RMB		1
ROWOFF RMB		1
      
		END START